@@ -1895,7 +1895,9 @@ module.exports = {
 		"18.3.9",
 		"18.3.11",
 		"18.3.12",
-		"18.3.13"
+		"18.3.13",
+		"18.3.14",
+		"18.3.15"
 	],
 	"102.0.4962.3": [
 		"19.0.0-alpha.1",
@@ -1981,7 +1983,11 @@ module.exports = {
 		"19.0.14",
 		"19.0.15",
 		"19.0.16",
-		"19.0.17"
+		"19.0.17",
+		"19.1.0",
+		"19.1.1",
+		"19.1.2",
+		"19.1.3"
 	],
 	"103.0.5044.0": [
 		"20.0.0-alpha.1",
@@ -2057,6 +2063,12 @@ module.exports = {
 		"20.1.3",
 		"20.1.4"
 	],
+	"104.0.5112.124": [
+		"20.2.0",
+		"20.3.0",
+		"20.3.1",
+		"20.3.2"
+	],
 	"105.0.5187.0": [
 		"21.0.0-alpha.1",
 		"21.0.0-alpha.2",
@@ -2100,7 +2112,9 @@ module.exports = {
 		"22.0.0-nightly.20220905"
 	],
 	"106.0.5249.40": [
-		"21.0.0-beta.6"
+		"21.0.0-beta.6",
+		"21.0.0-beta.7",
+		"21.0.0-beta.8"
 	],
 	"105.0.5129.0": [
 		"21.0.0-nightly.20220628",
@@ -2121,15 +2135,54 @@ module.exports = {
 		"21.0.0-nightly.20220718",
 		"21.0.0-nightly.20220719"
 	],
-	"107.0.5274.0": [
-		"22.0.0-nightly.20220908"
+	"106.0.5249.51": [
+		"21.0.0"
+	],
+	"106.0.5249.61": [
+		"21.0.1"
+	],
+	"106.0.5249.91": [
+		"21.1.0"
+	],
+	"106.0.5249.103": [
+		"21.1.1"
 	],
 	"107.0.5286.0": [
+		"22.0.0-alpha.1",
 		"22.0.0-nightly.20220909",
 		"22.0.0-nightly.20220912",
 		"22.0.0-nightly.20220913",
 		"22.0.0-nightly.20220914",
 		"22.0.0-nightly.20220915",
-		"22.0.0-nightly.20220916"
+		"22.0.0-nightly.20220916",
+		"22.0.0-nightly.20220919",
+		"22.0.0-nightly.20220920",
+		"22.0.0-nightly.20220921",
+		"22.0.0-nightly.20220922",
+		"22.0.0-nightly.20220923",
+		"22.0.0-nightly.20220926",
+		"22.0.0-nightly.20220927",
+		"22.0.0-nightly.20220928",
+		"23.0.0-nightly.20220929",
+		"23.0.0-nightly.20220930",
+		"23.0.0-nightly.20221003"
+	],
+	"108.0.5329.0": [
+		"22.0.0-alpha.3",
+		"22.0.0-alpha.4",
+		"22.0.0-alpha.5",
+		"23.0.0-nightly.20221004",
+		"23.0.0-nightly.20221005",
+		"23.0.0-nightly.20221006",
+		"23.0.0-nightly.20221007",
+		"23.0.0-nightly.20221010",
+		"23.0.0-nightly.20221011",
+		"23.0.0-nightly.20221012",
+		"23.0.0-nightly.20221013",
+		"23.0.0-nightly.20221014",
+		"23.0.0-nightly.20221017"
+	],
+	"107.0.5274.0": [
+		"22.0.0-nightly.20220908"
 	]
 };
\ No newline at end of file
